@@ -5,7 +5,8 @@ import pandas as pd
 import plotly.graph_objects as go
 from plotly.subplots import make_subplots
 
-from magnumapi.geometry.CosThetaGeometry import CosThetaGeometry
+from magnumapi.geometry.Geometry import Geometry
+from magnumapi.geometry.GeometryFactory import GeometryFactory
 
 
 class OptimizationCockpitWidget:
@@ -245,35 +246,13 @@ class OptimizationCockpitWidget:
         fit_dct = fit_row.to_dict('records')[0]
         fit_input = self.gen_opt.update_parameters(self.block_inputs, fit_dct)
 
-        geometry = CosThetaGeometry.with_roxie_relative_angle_definition_dict(fit_input, self.cadata)
+        geometry = GeometryFactory.init_with_dict(fit_input, self.cadata)
         geometry.build_blocks()
 
-        go_scatter = OptimizationCockpitWidget.create_plotly_scatter_blocks(geometry)
+        go_scatter = Geometry.create_plotly_scatters(geometry.blocks)
 
         max_number_of_blocks = int(self.optim_input_df[self.optim_input_df['variable'] == 'nco']['xu'].sum())
         for i in range(max_number_of_blocks - len(go_scatter)):
             go_scatter.append(go.Scatter(x=[], y=[]))
 
         self.widget.add_traces(go_scatter, rows=row, cols=col)
-
-    @staticmethod
-    def create_plotly_scatter_blocks(geometry):
-        # ToDo: This should come from the geometry class
-        idx = 1
-        go_scatter = []
-        for block in geometry.blocks:
-            for area in block.areas:
-                x = []
-                y = []
-                for i in range(4):
-                    x.append(area.get_line(i).p1.x)
-                    y.append(area.get_line(i).p1.y)
-
-                x.append(area.get_line(0).p1.x)
-                y.append(area.get_line(0).p1.y)
-
-                go_scatter.append(go.Scatter(x=x, y=y, fill="toself", fillcolor='white', marker=dict(size=1),
-                                             name='turn' + str(idx), line=go.scatter.Line(color='blue')))
-                idx += 1
-
-        return go_scatter
